@@ -1,7 +1,7 @@
 /*
  *  traywindow.cpp  -  the KDE system tray applet
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2002-2022 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2002-2023 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -65,7 +65,7 @@ TrayWindow::TrayWindow(MainWindow* parent)
     connect(theApp(), &KAlarmApp::alarmEnabledToggled, this, &TrayWindow::setEnabledStatus);
     contextMenu()->addSeparator();
 
-    mActionNew = new NewAlarmAction(false, i18nc("@action", "&New Alarm"), this);
+    mActionNew = new NewAlarmAction(false, i18nc("@action", "New Alarm"), this);
     addAction(QStringLiteral("tNew"), mActionNew);
     contextMenu()->addAction(mActionNew);
     connect(mActionNew, &NewAlarmAction::selected, this, &TrayWindow::slotNewAlarm);
@@ -330,15 +330,15 @@ QString TrayWindow::tooltipAlarmText() const
 
     // Get today's and tomorrow's alarms, sorted in time order
     int i, iend;
-    QList<TipItem> items;    //clazy:exclude=inefficient-qlist,inefficient-qlist-soft   QList is better than QVector for insertions
-    QVector<KAEvent> events = KAlarm::getSortedActiveEvents(const_cast<TrayWindow*>(this), &mAlarmsModel);
+    QList<TipItem> items;
+    QList<KAEvent> events = KAlarm::getSortedActiveEvents(const_cast<TrayWindow*>(this), &mAlarmsModel);
     for (i = 0, iend = events.count();  i < iend;  ++i)
     {
         KAEvent* event = &events[i];
-        if (event->actionSubType() == KAEvent::MESSAGE)
+        if (event->actionSubType() == KAEvent::SubAction::Message)
         {
             TipItem item;
-            QDateTime dateTime = event->nextTrigger(KAEvent::DISPLAY_TRIGGER).effectiveKDateTime().toLocalZone().qDateTime();
+            QDateTime dateTime = event->nextTrigger(KAEvent::Trigger::Display).effectiveKDateTime().toLocalZone().qDateTime();
             if (dateTime > tomorrow.qDateTime())
                 break;   // ignore alarms after tomorrow at the current clock time
             item.dateTime = dateTime;
@@ -399,4 +399,6 @@ void TrayWindow::removeWindow(MainWindow* win)
         mAssocMainWindow = nullptr;
 }
 
+#include "moc_traywindow.cpp"
+
 // vim: et sw=4:
